#
# spec file for package python-flask-restx
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-flask-restx
Version:        1.1.0
Release:        1.1
Summary:        Framework for fast, easy and documented API development with Flask
License:        BSD-3-Clause
URL:            https://github.com/python-restx/flask-restx
Source:         https://github.com/python-restx/flask-restx/archive/%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#python-restx/flask-restx#552
Patch0:         support-new-werkzeug.patch
BuildRequires:  %{python_module Faker}
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module aniso8601}
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module blinker}
BuildRequires:  %{python_module jsonschema}
BuildRequires:  %{python_module jsonschema}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-benchmark}
BuildRequires:  %{python_module pytest-flask}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module q}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tzlocal}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask
Requires:       python-Werkzeug
Requires:       python-aniso8601
Requires:       python-jsonschema
Requires:       python-pytz
BuildArch:      noarch
%python_subpackages

%description
Flask-RESTX is a community driven fork of Flask-RESTPlus. It is an extension for Flask
that adds support for quickly building REST APIs. It encourages best practices with
minimal setup. If you are familiar with Flask, Flask-RESTX should be easy to pick up.
It provides a coherent collection of decorators and tools to describe your API and expose
its documentation properly using Swagger.

%prep
%autosetup -p1 -n flask-restx-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# URLTest and EmailTest require network
%pytest -k 'not (URLTest or EmailTest)'

%files %{python_files}
%doc README.rst CONTRIBUTING.rst
%license LICENSE
%{python_sitelib}/flask_restx
%{python_sitelib}/flask_restx-%{version}.dist-info

%changelog
* Fri Jul 28 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.1.0:
  * Update Swagger-UI to latest version to fix several security
    vulnerabiltiies.
  * Fix minor bug introduced in 1.0.5 that changed the behaviour of how
    flask-restx propagates exceptions. (#512)
  * Add support for Python 3.11 (requires update to invoke ^2.0.0)
  * Fix compatibility with upcoming release of Flask 2.3+. (#485)
  * Fix compatibility issue with werkzeug 2.1.0 (#423)
  * Drop support for python <3.7
- Drop patches merged_pr_463.patch, redirect.patch and werkzeug.patch.
- Add patch support-new-werkzeug.patch:
  * Support Werkzeug 2.35.
- Switch to pyproject macros.
- Stop using greedy globs in %%files.
- Remove Python 2 leftovers.
* Wed Oct  5 2022 John Vandenberg <jayvdb@gmail.com>
- Add upstream patch merged_pr_463.patch to support Werkzeug 2.2.
* Fri Jul 15 2022 Markéta Machová <mmachova@suse.com>
- Add upstream patches werkzeug.patch and redirect.patch to fix the tests.
* Mon Mar 21 2022 pgajdos@suse.com
- python-mock is actually not required for build
* Thu Feb 10 2022 Matej Cepl <mcepl@suse.com>
- Allow Pytest 6 (not sure why it was forbidden).
- Skip LoggingTest.test_override_app_level failing test
  (gh#python-restx/flask-restx#411).
* Tue Sep 21 2021 Sean Marlow <sean.marlow@suse.com>
- Update to v0.5.1
  + Optimize email regex (bsc#1190744)
* Sun Aug 15 2021 John Vandenberg <jayvdb@gmail.com>
- Fetch listed v0.5.0.tar.gz
* Mon Jul 26 2021 Sean Marlow <sean.marlow@suse.com>
- Update to v0.5.0
  + Fix Marshaled nested wildcard field with ordered=True
  + Fix Float Field Handling of None
  + Fix Werkzeug and Flask > 2.0 issues
  + Hotfix package.json
  + Stop calling got_request_exception when handled explicitly
  + Structure demo zoo app
  + Update Contributing.rst
  + Upgrade swagger-ui
- Update to v0.4.0
  + Fix Namespace error handlers when propogate_exceptions=True
  + pin flask and werkzeug due to breaking changes
  + The Flask/Blueprint API moved to the Scaffold base class
  + added specs-url-scheme option for API
- Update to v0.3.0
  + Make error handlers order of registration respected when
    handling errors
  + add prefix to config setting
  + Use relative path for `api.specs_url`
  + Allow example=False
  + Add support for recursive models
  + generate choices schema without collectionFormat
  + Catch TypeError in marshalling
  + Unable to access nested list propert
  + allow strict mode when validating model fields
  + Make it possible to include "unused" models in the generated
    swagger documentation
* Tue Apr 27 2021 Sean Marlow <sean.marlow@suse.com>
- Add missing python2 requirement.
* Mon Apr 12 2021 Sean Marlow <sean.marlow@suse.com>
- Ignore test_handle_non_api_error test which is dependent on
  werkzeug version.
* Thu Sep 24 2020 Petr Cervinka <petr@cervinka.net>
- Set pytest version < 6 in build requirements
* Sat May  2 2020 Petr Cervinka <petr@cervinka.net>
- Initial version
